pub enum Parity {
Eip155(u64),
NonEip155(bool),
Parity(bool),
}Expand description
The parity of the signature, stored as either a V value (which may include a chain id), or the y-parity.
Variants
Eip155(u64)
Explicit V value. May be EIP-155 modified.
NonEip155(bool)
Non-EIP155. 27 or 28.
Parity(bool)
Parity flag. True for odd.
Implementations
Sourceimpl Parity
impl Parity
Sourcepub const fn y_parity_byte(&self) -> u8
pub const fn y_parity_byte(&self) -> u8
Return the y-parity as 0 or 1
Sourcepub const fn y_parity_byte_non_eip155(&self) -> Option<u8>
pub const fn y_parity_byte_non_eip155(&self) -> Option<u8>
Return the y-parity byte as 27 or 28, in the case of a non-EIP155 signature.
Sourcepub const fn strip_chain_id(&self) -> Parity
pub const fn strip_chain_id(&self) -> Parity
Converts an EIP-155 V value to a non-EIP-155 V value.
This is a nop for non-EIP-155 values.
Sourcepub const fn with_chain_id(self, chain_id: u64) -> Parity
pub const fn with_chain_id(self, chain_id: u64) -> Parity
Applies EIP-155 with the given chain ID.
Sourcepub const fn recid(&self) -> RecoveryId
pub const fn recid(&self) -> RecoveryId
Determines the recovery ID.
Sourcepub const fn to_parity_bool(self) -> Parity
pub const fn to_parity_bool(self) -> Parity
Convert to a parity bool, dropping any V information.